Offline helper that expands a range of reference months in AAAAMM
format. Useful to request several months from caged_download() or
caged_fetch() without querying the server first.
pkgdown/extra.css
Skip to contentsOffline helper that expands a range of reference months in AAAAMM
format. Useful to request several months from caged_download() or
caged_fetch() without querying the server first.